@@ -1,7 +1,7 @@
 #
 # This file is part of Dist-Zilla-PluginBundle-RSRCHBOY
 #
-# This software is Copyright (c) 2013 by Chris Weyl.
+# This software is Copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by Chris Weyl.
 #
 # This is free software, licensed under:
 #
@@ -9,8 +9,8 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.073-5-gd31da0b
-$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.074';
+# git description: 0.074-1-g956fa42
+$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.075';
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
 
@@ -239,7 +239,10 @@ sub configure {
         { version_regexp => '^(\d.\d+(_\d\d)?)(-TRIAL|)$' },
     ]);
 
-    $self->add_plugins('ContributorsFromGit');
+    $self->add_plugins(qw{
+        CopyrightYearFromGit
+        ContributorsFromGit
+    });
 
     $self->add_bundle('Git::CheckFor');
 
@@ -357,7 +360,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.074 of Dist::Zilla::PluginBundle::RSRCHBOY - released April 15, 2017 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.075 of Dist::Zilla::PluginBundle::RSRCHBOY - released May 08, 2017 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
@@ -491,7 +494,7 @@ Sergey Romanov <complefor@rambler.ru>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Chris Weyl.
+This software is Copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by Chris Weyl.
 
 This is free software, licensed under:
 
